===============================
kloudbuster
===============================

KloudBuster is a open source tool that allows anybody to load any Neutron OpenStack cloud at massive data plane scale swiftly and effortlessly.

Please feel here a long description which must be at least 3 lines wrapped on
80 cols, so that distribution package maintainers can use it in their packages.
Note that this is a hard requirement.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/kloudbuster
* Source: http://git.openstack.org/cgit/openstack/kloudbuster
* Bugs: http://bugs.launchpad.net/kloudbuster

Features
--------

* TODO
